@@ -9,6 +9,7 @@ from __future__ import absolute_import, unicode_literals
 import logging
 import json
 import re
+import io
 import time
 from copy import copy
 from functools import reduce, wraps
@@ -23,12 +24,14 @@ import requests
 from requests.models import Response
 from future.utils import raise_from as _raise
 import nipyapi
+from nipyapi.config import default_string_encoding as DEF_ENCODING
 
 __all__ = ['dump', 'load', 'fs_read', 'fs_write', 'filter_obj',
            'wait_to_complete', 'is_endpoint_up', 'set_endpoint',
            'start_docker_containers', 'DockerContainer',
            'infer_object_label_from_class', 'bypass_slash_encoding',
-           'exception_handler', 'enforce_min_ver', 'check_version'
+           'exception_handler', 'enforce_min_ver', 'check_version',
+           'validate_parameters_versioning_support'
            ]
 
 log = logging.getLogger(__name__)
@@ -36,7 +39,8 @@ log = logging.getLogger(__name__)
 
 def dump(obj, mode='json'):
     """
-    Dumps a native datatype object or swagger entity to json or yaml, defaults to json
+    Dumps a native datatype object or swagger entity to json or yaml
+        defaults to json
 
     Args:
         obj (varies): The native datatype object or swagger type to serialise
@@ -46,14 +50,8 @@ def dump(obj, mode='json'):
 
     """
     assert mode in ['json', 'yaml']
-    unset = False
-    if nipyapi.config.nifi_config.api_client is None:
-        unset = True
-        nipyapi.config.nifi_config.api_client = nipyapi.nifi.ApiClient()
-
-    prepared_obj = nipyapi.config.nifi_config.api_client.sanitize_for_serialization(obj)
-    if unset:
-        nipyapi.config.nifi_config.api_client = None
+    api_client = nipyapi.nifi.ApiClient()
+    prepared_obj = api_client.sanitize_for_serialization(obj)
     try:
         out = json.dumps(
             obj=prepared_obj,
@@ -130,8 +128,12 @@ def fs_write(obj, file_path):
     Returns: The object that was written
     """
     try:
-        with open(str(file_path), 'w') as f:
-            f.write(obj)
+        with io.open(str(file_path), 'w', encoding=DEF_ENCODING) as f:
+            if isinstance(obj, bytes):
+                obj_str = obj.decode(DEF_ENCODING)
+            else:
+                obj_str = obj
+            f.write(obj_str)
         return obj
     except TypeError as e:
         raise e
@@ -147,7 +149,7 @@ def fs_read(file_path):
     Returns: The object that was read
     """
     try:
-        with open(str(file_path), 'r') as f:
+        with io.open(str(file_path), 'r', encoding=DEF_ENCODING) as f:
             return f.read()
     except IOError as e:
         raise e
@@ -465,8 +467,8 @@ def strip_snapshot(java_version):
 
 def check_version(base, comparator=None, service='nifi'):
     """
-    Compares version 'a' against either version 'b', or the version of the
-    currently connected service instance.
+    Compares version base against either version comparator, or the version
+    of the currently connected service instance.
 
     Since NiFi is java, it may return a version with -SNAPSHOT as part of it.
     As such, that will be stripped from either the comparator version or
@@ -478,21 +480,44 @@ def check_version(base, comparator=None, service='nifi'):
         service (str): The service to test the version against, currently
             only supports NiFi
 
-    Returns (int): -1 if a is lower, 0 if equal, and 1 if newer
+    Returns (int): -1/0/1 if base is lower/equal/newer than comparator
 
     """
     assert isinstance(base, six.string_types)
     assert comparator is None or isinstance(comparator, six.string_types)
-    assert service == 'nifi'
+    assert service in ['nifi', 'registry']
     # This call currently only supports NiFi
     ver_a = version.parse(base)
     if comparator:
         # if b is set, we compare the passed versions
         comparator = strip_snapshot(comparator)
         ver_b = version.parse(comparator)
+    elif service == 'registry':
+        try:
+            config = nipyapi.config.registry_config
+            if config.api_client is None:
+                config.api_client = nipyapi.registry.ApiClient()
+            reg_swagger_def = config.api_client.call_api(
+                resource_path='/swagger/swagger.json',
+                method='GET', _preload_content=False,
+                auth_settings=['tokenAuth', 'Authorization']
+            )
+            reg_json = load(reg_swagger_def[0].data)
+            ver_b = version.parse(reg_json['info']['version'])
+        except nipyapi.registry.rest.ApiException as e:
+            if e.status == 404:
+                log.warning("Unable to retrieve swagger.json from registry "
+                            "to check version, assuming older than 0.3")
+                ver_b = version.parse('0.2.0')
+            else:
+                raise
     else:
-        # if b not set, we compare a against the connected nifi instance
-        ver_b = version.parse(strip_snapshot(nipyapi.system.get_nifi_version_info().ni_fi_version))
+        # Working with NiFi
+        ver_b = version.parse(
+            strip_snapshot(
+                nipyapi.system.get_nifi_version_info().ni_fi_version
+            )
+        )
     if ver_b > ver_a:
         return -1
     if ver_b < ver_a:
@@ -500,18 +525,30 @@ def check_version(base, comparator=None, service='nifi'):
     return 0
 
 
-def enforce_min_ver(min_version, bool_response=False):
+def validate_parameters_versioning_support():
+    """Convenience method to check if Parameters are supported"""
+    nifi_check = enforce_min_ver('1.10', bool_response=True)
+    registry_check = enforce_min_ver(
+        '0.6', service='registry', bool_response=True)
+    if nifi_check or registry_check:
+        log.warning("Connected NiFi Registry may not support "
+                    "Parameter Contexts and they may be lost in "
+                    "Version Control")
+
+
+def enforce_min_ver(min_version, bool_response=False, service='nifi'):
     """
     Raises an error if target NiFi environment is not minimum version
     Args:
         min_version (str): Version to check against
         bool_response (bool): If True, will return True instead of
          raising error
+     service: nifi or registry
 
     Returns:
         (bool) or (NotImplementedError)
     """
-    if check_version(min_version) == 1:
+    if check_version(min_version, service=service) == 1:
         if not bool_response:
             raise NotImplementedError(
                 "This function is not available "
