@@ -161,13 +161,14 @@ def delete_registry_bucket(bucket):
         _raise(ValueError(e), e)
 
 
-def get_registry_bucket(identifier, identifier_type='name'):
+def get_registry_bucket(identifier, identifier_type='name', greedy=True):
     """
     Filters the Bucket list to a particular identifier
 
     Args:
         identifier (str): the filter string
         identifier_type (str): the param to filter on
+        greedy (bool): False for exact match, True for greedy match
 
     Returns:
         None for no matches, Single Object for unique match,
@@ -175,7 +176,8 @@ def get_registry_bucket(identifier, identifier_type='name'):
     """
     with nipyapi.utils.rest_exceptions():
         obj = list_registry_buckets()
-    return nipyapi.utils.filter_obj(obj, identifier, identifier_type)
+    return nipyapi.utils.filter_obj(
+        obj, identifier, identifier_type, greedy=greedy)
 
 
 def list_flows_in_bucket(bucket_id):
@@ -192,7 +194,8 @@ def list_flows_in_bucket(bucket_id):
         return nipyapi.registry.BucketFlowsApi().get_flows(bucket_id)
 
 
-def get_flow_in_bucket(bucket_id, identifier, identifier_type='name'):
+def get_flow_in_bucket(bucket_id, identifier, identifier_type='name',
+                       greedy=True):
     """
     Filters the Flows in a Bucket against a particular identifier
 
@@ -200,6 +203,7 @@ def get_flow_in_bucket(bucket_id, identifier, identifier_type='name'):
         bucket_id (str): UUID of the Bucket to filter against
         identifier (str): The string to filter on
         identifier_type (str): The param to check
+        greedy (bool): False for exact match, True for greedy match
 
     Returns:
         None for no matches, Single Object for unique match,
@@ -207,7 +211,8 @@ def get_flow_in_bucket(bucket_id, identifier, identifier_type='name'):
     """
     with nipyapi.utils.rest_exceptions():
         obj = list_flows_in_bucket(bucket_id)
-    return nipyapi.utils.filter_obj(obj, identifier, identifier_type)
+    return nipyapi.utils.filter_obj(
+        obj, identifier, identifier_type, greedy=greedy)
 
 
 def save_flow_ver(process_group, registry_client, bucket, flow_name=None,
@@ -240,36 +245,25 @@ def save_flow_ver(process_group, registry_client, bucket, flow_name=None,
         target_pg = nipyapi.canvas.get_process_group(process_group.id, 'id')
     else:
         target_pg = process_group
+    flow_dto = nipyapi.nifi.VersionedFlowDTO(
+        bucket_id=bucket.identifier,
+        comments=comment,
+        description=desc,
+        flow_name=flow_name,
+        flow_id=flow_id,
+        registry_id=registry_client.id
+    )
     if nipyapi.utils.check_version('1.10.0') <= 0:
-        body = nipyapi.nifi.StartVersionControlRequestEntity(
-            process_group_revision=target_pg.revision,
-            versioned_flow=nipyapi.nifi.VersionedFlowDTO(
-                bucket_id=bucket.identifier,
-                comments=comment,
-                description=desc,
-                flow_name=flow_name,
-                flow_id=flow_id,
-                registry_id=registry_client.id,
-                action='FORCE_COMMIT' if force else 'COMMIT'
-            )
-        )
-    else:
         # no 'action' property in versions < 1.10
-        body = nipyapi.nifi.StartVersionControlRequestEntity(
-            process_group_revision=target_pg.revision,
-            versioned_flow={
-                'bucketId': bucket.identifier,
-                'comments': comment,
-                'description': desc,
-                'flowName': flow_name,
-                'flowId': flow_id,
-                'registryId': registry_client.id
-            }
-        )
+        flow_dto.action = 'FORCE_COMMIT' if force else 'COMMIT'
     with nipyapi.utils.rest_exceptions():
+        nipyapi.utils.validate_parameters_versioning_support()
         return nipyapi.nifi.VersionsApi().save_to_flow_registry(
             id=target_pg.id,
-            body=body
+            body=nipyapi.nifi.StartVersionControlRequestEntity(
+                process_group_revision=target_pg.revision,
+                versioned_flow=flow_dto
+            )
         )
 
 
@@ -523,6 +517,8 @@ def create_flow_version(flow, flow_snapshot, refresh=True):
         for obj in [target_bucket, target_flow]:
             for p in bad_params:
                 obj.__setattr__(p, None)
+        nipyapi.utils.validate_parameters_versioning_support()
+        ecs = flow_snapshot.external_controller_services
         return nipyapi.registry.BucketFlowsApi().create_flow_version(
             bucket_id=target_bucket.identifier,
             flow_id=target_flow.identifier,
@@ -530,6 +526,8 @@ def create_flow_version(flow, flow_snapshot, refresh=True):
                 flow=target_flow,
                 bucket=target_bucket,
                 flow_contents=flow_snapshot.flow_contents,
+                parameter_contexts=flow_snapshot.parameter_contexts,
+                external_controller_services=ecs,
                 snapshot_metadata=VfsMd(
                     version=target_flow.version_count + 1,
                     comments=flow_snapshot.snapshot_metadata.comments,
@@ -689,6 +687,7 @@ def import_flow_version(bucket_id, encoded_flow=None, file_path=None,
                          " add this version to, or flow_name must be a unique "
                          "name for a flow in this bucket, but not both")
     # Now write the new version
+    nipyapi.utils.validate_parameters_versioning_support()
     return create_flow_version(
         flow=ver_flow,
         flow_snapshot=imported_flow,
